@@ -12,7 +12,21 @@ try:
     from pyjsonata import jsonata
 except ImportError:
     AIOFLUREEDB_HAS_JSONATA = False
-    def jsonate(xform, json_data):
+    def jsonata(xform, json_data):
+        """We don't want to fail on import, we only want to fail on usage
+
+        Parameters
+        ----------
+
+        xform : str
+            Transformation code
+        json_data : str
+            Source json
+        Raises
+        ------
+        RuntimeError
+            Raised always because of missing jsonata library
+        """
         raise RuntimeError("Domain-API method uses a jsonata transformation-file while pyjsonata module is not available.")
 
 def _detemplate_object(kwargs, template):
@@ -134,11 +148,15 @@ class _ExpanderFunction:
         self.template = template
         self.expander = expander
 
-    def __call__(self, **kwargs):
+    def __call__(self, *args, **kwargs):
         """Expand template with operation
 
         Parameters
         ----------
+
+        args : list
+            Positional arguments, these will be ignored!
+
         kwargs : dict
             key value dict with arguments
         """
@@ -290,7 +308,10 @@ class _Transformer:
         # Otherwise, we transform the query result as defined in the transformation jsonata file
         if self.xform is None:
             return query_result
-        return json.loads(jsonata(self.xform, json.dumps(query_result)))
+        rval = jsonata(self.xform, json.dumps(query_result))
+        if rval == 'undefined':
+            return None
+        return json.loads(rval)
 
 
 class _TemplateCollection:
@@ -338,6 +359,11 @@ class _TemplateCollection:
         templates : list
             Names of the templates of this type
 
+        Raises
+        ------
+        RuntimeError
+            Raised if jsonata used but not available on platform
+
         """
         if templates:
             templatedir = os.path.join(self.apimapdir, subdir)
@@ -364,9 +390,8 @@ class _TemplateCollection:
                     with open(xform_path) as xform_file:
                         if AIOFLUREEDB_HAS_JSONATA or deep_fail:
                             self.xform[template] = xform_file.read()
-                        else:
-                            if not ignore_xform:
-                                raise RuntimeError("API-Map uses jsonata transformation files while pyjsonata module is not available.")
+                        elif not ignore_xform:
+                            raise RuntimeError("API-Map uses jsonata transformation files while pyjsonata module is not available.")
                 except FileNotFoundError:
                     pass
 
@@ -408,11 +433,15 @@ class _TemplateCollection:
                 self.collection = collection
                 self.database = database
 
-            def __call__(self, **kwargs):
+            def __call__(self, *args, **kwargs):
                 """Invocation function object
 
                 Parameters
                 ----------
+
+                args : list
+                    Positional arguments, these will be ignored!
+
                 kwargs : dict
                     Keyword arguments
 
@@ -444,11 +473,15 @@ class _TemplateCollection:
                 if name in collection.xform:
                     self.xform = collection.xform[name]
 
-            def __call__(self, **kwargs):
+            def __call__(self, *args, **kwargs):
                 """Invoke
 
                 Parameters
                 ----------
+
+                args : list
+                    Positional arguments, these will be ignored!
+
                 kwargs : dict
                     keyword arguments
 
@@ -475,11 +508,15 @@ class _TemplateCollection:
                 self.query = query
                 self.database = database
 
-            async def __call__(self, **kwargs):
+            async def __call__(self, *args, **kwargs):
                 """Async Invoke
 
                 Parameters
                 ----------
+
+                args : list
+                    Positional arguments, these will be ignored!
+
                 kwargs : dict
                     Keyword arguments
 
@@ -488,7 +525,6 @@ class _TemplateCollection:
                 dict or list
                     Query result from flureedb, possibly transformed
                 """
-                print(kwargs)
                 ll_query = self.query(**kwargs)
                 ll_result = await self.database.flureeql.query.raw(ll_query())
                 return ll_query(ll_result)
